@@ -1,5 +1,5 @@
 
-.onLoad <- function(libname, pkgname) {
+.onAttach <- function(libname, pkgname) {
 
 	drv <- getOption("sqldf.driver")
 	drv <- if (is.null(drv) || drv == "") {
